==> ant-design-vue-2.0.0-rc.9.jar: META-INF/resources/webjars/ant-design-vue/2.0.0-rc.9/lib/vc-tabs/src/TabContent.d.ts <==
declare var _default: import("vue").DefineComponent<{
    animated: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    animatedWithMargin: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    activeKey: import("vue-types").VueTypeDef<import("../../_util/type").Key>;
    tabBarPosition: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    direction: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    destroyInactiveTabPane: import("vue-types").VueTypeValidableDef<boolean>;
    children: import("vue-types").VueTypeValidableDef<any>;
}, any, any, {
    classes(): {
        [x: string]: boolean;
        [x: number]: boolean;
    };
}, {
    getTabPanes(children: any): any[];
}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    prefixCls: string;
    direction: string;
    animated: boolean;
    tabBarPosition: string;
    animatedWithMargin: boolean;
} & {
    children?: any;
    activeKey?: import("../../_util/type").Key;
    destroyInactiveTabPane?: boolean;
}>, {
    prefixCls: string;
    direction: string;
    animated: boolean;
    tabBarPosition: string;
    animatedWithMargin: boolean;
}>;
export default _default;

==> ant-design-vue-2.1.3.jar: META-INF/resources/webjars/ant-design-vue/2.1.3/lib/vc-tabs/src/TabContent.d.ts <==
declare var _default: import("vue").DefineComponent<{
    animated: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    animatedWithMargin: import("vue-types").VueTypeValidableDef<boolean> & {
        default: boolean;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    } & {
        default: string;
    };
    activeKey: import("vue-types").VueTypeDef<string | number>;
    tabBarPosition: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    direction: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    destroyInactiveTabPane: import("vue-types").VueTypeValidableDef<boolean>;
    children: import("vue-types").VueTypeValidableDef<any>;
}, any, any, {
    classes(): {
        [x: string]: boolean;
        [x: number]: boolean;
    };
}, {
    getTabPanes(children: any): any[];
}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    prefixCls: string;
    direction: string;
    animated: boolean;
    tabBarPosition: string;
    animatedWithMargin: boolean;
} & {
    children?: any;
    activeKey?: string | number;
    destroyInactiveTabPane?: boolean;
}>, {
    prefixCls: string;
    direction: string;
    animated: boolean;
    tabBarPosition: string;
    animatedWithMargin: boolean;
}>;
export default _default;
